/* global Bdf,$$ */
/**
 * Objet global définissant l'espace de nom Main
 * 
 * @namespace Main
 */
var Main = {};

Main.initLayout = function () {
    Bdf.Api.init();
    var fichothequeRoot = _initFichothequeRoot();
    $$("main_body_tool").html(Bdf.render("main:tool", {}));
    $$("main_body_tool_onoff").click(function () {
        _onoff("main_body_list");
    });
    $$("main_body_tool_decrease").click(function () {
        _resize("main_body_list", -50);
    });
    $$("main_body_tool_increase").click(function () {
        _resize("main_body_list", 50);
    });
    $$("main_body_edition_iframe").on("load", function (event) {
        _showToolbar(false);
        let outside = false;
        let pathName;
        let search;
        try {
            pathName = this.contentWindow.location.pathname;
            search = this.contentWindow.location.search;
        }  catch(error) {
            outside = true;
        }
        if (outside) {
            $(this).addClass("main-WebContent");
        } else {
            if (_isWebContent(pathName, search)) {
                $(this).addClass("main-WebContent");
            } else {
                $(this).removeClass("main-WebContent");
            }
            if (search) {
                if (search.indexOf("bdf-flag=updateCorpusTree") > -1) {
                    Main.updateCorpusTree();
                }
                if (search.indexOf("bdf-flag=updateCollections") > -1) {
                    Main.updateCollections();
                }
            }
            if (pathName.startsWith(fichothequeRoot)) {
                _checkPath(pathName, this.contentWindow);
            }
        }
    });
    _initWidth();
    
    
    function _onoff(layoutId) {
        let $layout = $$(layoutId);
        if ($layout.hasClass("hidden")) {
            $layout.removeClass("hidden");
        } else {
            $layout.addClass("hidden");
        }
    }
    
    function _resize(layoutId, widthDiff) {
        let $layout = $$(layoutId);
        let newWidth = $layout.width() + widthDiff;
        if (newWidth > 199) {
            $layout.width(newWidth);
            let localData = Bdf.getMainLocalStorage();
            if (localData) {
                localData[layoutId] = newWidth;
                Bdf.putMainLocalStorage(localData);
            }
        }
    }
    
    function _initWidth() {
        let localData = Bdf.getMainLocalStorage();
        let layoutId = "main_body_list";
        if (localData) {
            if (localData.hasOwnProperty(layoutId)) {
                let width = parseInt(localData[layoutId]);
                if (width > 199) {
                    $$(layoutId).width(width);
                }
            }
        }
    }
        
    function _isWebContent(pathName, search) {
        if ((search) && (search.indexOf("bdf-framestyle=border") > -1)) {
            return true;
        }
        let idx = pathName.lastIndexOf("/");
        if (idx > -1) {
            pathName = pathName.substr(idx + 1);
        }
        idx = pathName.indexOf(".");
        if (idx > -1) {
            return true;
        } else {
            return false;
        }
    }
    
    function _initFichothequeRoot() {
        let currentPathName = window.location.pathname;
        let lastIndex = currentPathName.lastIndexOf("/");
        return currentPathName.substr(0, lastIndex + 1);
    }
    
    function _checkPath(pathName, contentWindow) {
        let ficheTest = pathName.match(/\/fiches\/([a-z][a-z0-9]*)-([0-9]+)(-[_a-z0-9]+)?\.html$/);
        if (ficheTest) {
            let corpus = ficheTest[1];
            let id = ficheTest[2];
            Bdf.api.loadFiche({
               corpus: corpus,
               id: id,
               callback: function (data) {
                   if (data.fiche) {
                        let editable = data.fiche.editable;
                        let array = _checkToc( contentWindow.document);
                        let html = Bdf.render("main:editiontoolbar", {
                            corpus: corpus,
                            id: id,
                            editable: editable,
                            path: pathName,
                            toc: array
                        });
                        $$("main_body_edition_toolbar").html(html);
                        if (html.length > 0) {
                            _showToolbar(true);
                            $(contentWindow).on('beforeunload', function(e) {
                                _showToolbar(false);
                            });
                        }
                    }
               }
            });
        }
    }
    
    function _showToolbar(display) {
        if (display) {
            $$("main_body_edition_toolbar").removeClass("hidden");
        } else {
            $$("main_body_edition_toolbar").addClass("hidden");
        }
    }
    
    function _checkToc(document) {
        let array = new Array();
        $(document).find("h2, section > h1").each(function (index, element) {
            let id = element.id;
            if (!id) {
                id = Bdf.generateId();
                element.id = id;
            }
            let $element = $(element);
            let text = $element.text();
            if (!$element.is(":hidden")) {
                array.push({
                    id: id,
                    text: text
                });
            }
        });
        return array;
    }
    
};

Main.updateCollections = function () {
    try {
        let listWindow = $$.one("main_body_list_iframe").contentWindow;
        let search = listWindow.location.search;
        if ((search) && (search.indexOf("page=collections") > -1)) {
            listWindow.location.reload();
        } else {
            listWindow.location = "main?page=collections";
        }
     }  catch(error) {
    }
};

Main.updateCorpusTree = function () {
    Bdf.Ajax.loadSubsetTrees("corpus", false, _update);
    
    function _update(subsetTrees) {
        let menuCorpusUpdate = Bdf.getFunction("menu:updateCorpusTree");
        if (menuCorpusUpdate) {
            menuCorpusUpdate(subsetTrees.corpus);
        }
    }
};


/******************************************************************************
 * Initialisation
 ******************************************************************************/

$(function () {
    Bdf.initTemplates();
    Main.initLayout();
});
